phovea_data_hdf [![Phovea][phovea-image]][phovea-url] [![NPM version][npm-image]][npm-url] [![Build Status][travis-image]][travis-url] [![Dependency Status][daviddm-image]][daviddm-url]
=====================

Data provider plugin for loading data stored as [Hierarchical Data Format (HDF)](http://www.hdfgroup.org/).

Installation
------------

```
git clone https://github.com/phovea/phovea_data_hdf.git
cd phovea_data_hdf
npm install
```

Testing
-------

```
npm test
```

Building
--------

```
npm run build
```



***

<a href="https://caleydo.org"><img src="http://caleydo.org/assets/images/logos/caleydo.svg" align="left" width="200px" hspace="10" vspace="6"></a>
This repository is part of **[Phovea](http://phovea.caleydo.org/)**, a platform for developing web-based visualization applications. For tutorials, API docs, and more information about the build and deployment process, see the [documentation page](http://phovea.caleydo.org).


[phovea-image]: https://img.shields.io/badge/Phovea-Server%20Plugin-10ACDF.svg
[phovea-url]: https://phovea.caleydo.org
[npm-image]: https://badge.fury.io/js/phovea_data_hdf.svg
[npm-url]: https://npmjs.org/package/phovea_data_hdf
[travis-image]: https://travis-ci.org/phovea/phovea_data_hdf.svg?branch=master
[travis-url]: https://travis-ci.org/phovea/phovea_data_hdf
[daviddm-image]: https://david-dm.org/phovea/phovea_data_hdf/status.svg
[daviddm-url]: https://david-dm.org/phovea/phovea_data_hdf
